# Generated by Django 4.2.25 on 2025-11-11 00:00

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aapayout", "0005_fleet_finalized_fleet_finalized_at_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="lootpool",
            name="scout_bonus_percentage",
            field=models.DecimalField(
                decimal_places=2,
                default=10,
                help_text="Scout bonus percentage (default: 10%)",
                max_digits=5,
            ),
        ),
    ]
